==> diff2html-4.0.14.tgz: package/src/file-list-printer.js <==
/*
 *
 * FileListPrinter (file-list-printer.js)
 * Author: nmatpt
 *
 */

(function() {
  var printerUtils = require('./printer-utils.js').PrinterUtils;
  var Utils = require('./utils.js').Utils;

  var hoganUtils;

  var baseTemplatesPath = 'file-summary';
  var iconsBaseTemplatesPath = 'icon';

  function FileListPrinter(config) {
    this.config = config;

    var HoganJsUtils = require('./hoganjs-utils.js').HoganJsUtils;
    hoganUtils = new HoganJsUtils(config);
  }

  FileListPrinter.prototype.generateFileList = function(diffFiles) {
    var lineTemplate = hoganUtils.template(baseTemplatesPath, 'line');

    var files = diffFiles.map(function(file) {
      var fileTypeName = printerUtils.getFileTypeIcon(file);
      var iconTemplate = hoganUtils.template(iconsBaseTemplatesPath, fileTypeName);

      return lineTemplate.render({
        fileHtmlId: printerUtils.getHtmlId(file),
        oldName: file.oldName,
        newName: file.newName,
        fileName: printerUtils.getDiffName(file),
        deletedLines: '-' + file.deletedLines,
        addedLines: '+' + file.addedLines
      }, {
        fileIcon: iconTemplate
      });
    }).join('\n');

    const effectiveChangedLines = global.coveredDiffStatementNewLines + global.uncoveredDiffStatementNewLines;
    const diffStatementCoverageRate = effectiveChangedLines === 0 ? 0 : parseFloat((global.coveredDiffStatementNewLines / effectiveChangedLines * 100).toFixed(2));
    const overallStatementCoverageRate = Utils.getOverallLineCoverageRate(global.coverage);
    return hoganUtils.render(baseTemplatesPath, 'wrapper', {
      filesNumber: diffFiles.length,
      files: files,
      diffStatementNewLines: global.diffStatementNewLines,
      coveredDiffStatementNewLines: global.coveredDiffStatementNewLines,
      uncoveredDiffStatementNewLines: global.uncoveredDiffStatementNewLines,
      nonExecutableDiffStatementNewLines: global.nonExecutableDiffStatementNewLines,
      effectiveDiffStatementNewLines: global.coveredDiffStatementNewLines + global.uncoveredDiffStatementNewLines,
      diffStatementCoverageRate,
      overallStatementCoverageRate
    });
  };

  module.exports.FileListPrinter = FileListPrinter;
})();

==> diff2html-4.0.16.tgz: package/src/file-list-printer.js <==
/*
 *
 * FileListPrinter (file-list-printer.js)
 * Author: nmatpt
 *
 */

(function() {
  var printerUtils = require('./printer-utils.js').PrinterUtils;
  var Utils = require('./utils.js').Utils;

  var hoganUtils;

  var baseTemplatesPath = 'file-summary';
  var iconsBaseTemplatesPath = 'icon';

  function FileListPrinter(config) {
    this.config = config;

    var HoganJsUtils = require('./hoganjs-utils.js').HoganJsUtils;
    hoganUtils = new HoganJsUtils(config);
  }

  FileListPrinter.prototype.generateFileList = function(diffFiles) {
    var lineTemplate = hoganUtils.template(baseTemplatesPath, 'line');

    var files = diffFiles.map(function(file) {
      var fileTypeName = printerUtils.getFileTypeIcon(file);
      var iconTemplate = hoganUtils.template(iconsBaseTemplatesPath, fileTypeName);

      return lineTemplate.render({
        fileHtmlId: printerUtils.getHtmlId(file),
        oldName: file.oldName,
        newName: file.newName,
        fileName: printerUtils.getDiffName(file),
        deletedLines: '-' + file.deletedLines,
        addedLines: '+' + file.addedLines
      }, {
        fileIcon: iconTemplate
      });
    }).join('\n');

    const effectiveChangedLines = global.coveredDiffStatementNewLines + global.uncoveredDiffStatementNewLines;
    const diffStatementCoverageRate = effectiveChangedLines === 0 ? 0 : parseFloat((global.coveredDiffStatementNewLines / effectiveChangedLines * 100).toFixed(2));
    const {
      coveredLines,
      uncoveredLines,
      overallLineCoverageRate
    } = Utils.getOverallLineCoverageRate(global.coverage);
    global.coveredLines = coveredLines;
    global.uncoveredLines = uncoveredLines;
    global.overallStatementCoverageRate = overallLineCoverageRate;
    return hoganUtils.render(baseTemplatesPath, 'wrapper', {
      filesNumber: diffFiles.length,
      files: files,
      diffStatementNewLines: global.diffStatementNewLines,
      coveredDiffStatementNewLines: global.coveredDiffStatementNewLines,
      uncoveredDiffStatementNewLines: global.uncoveredDiffStatementNewLines,
      nonExecutableDiffStatementNewLines: global.nonExecutableDiffStatementNewLines,
      effectiveDiffStatementNewLines: global.coveredDiffStatementNewLines + global.uncoveredDiffStatementNewLines,
      diffStatementCoverageRate,
      coveredLines: global.coveredLines,
      uncoveredLines: global.uncoveredLines,
      allLines: global.coveredLines + global.uncoveredLines,
      overallStatementCoverageRate: global.overallStatementCoverageRate
    });
  };

  module.exports.FileListPrinter = FileListPrinter;
})();
